==> gdal-3.0.1.tar.gz: gdal-3.0.1/gnm/gnm_frmts/db/gnmdb.h <==
/******************************************************************************
 * $Id: gnmdb.h 7e07230bbff24eb333608de4dbd460b7312839d0 2017-12-11 19:08:47Z Even Rouault $
 *
 * Project:  GDAL/OGR Geography Network support (Geographic Network Model)
 * Purpose:  GNM db based generic driver.
 * Authors:  Mikhail Gusev (gusevmihs at gmail dot com)
 *           Dmitry Baryshnikov, polimax@mail.ru
 *
 ******************************************************************************
 * Copyright (c) 2014, Mikhail Gusev
 * Copyright (c) 2014-2015, NextGIS <info@nextgis.com>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 ****************************************************************************/

#include "gnm.h"

class GNMDatabaseNetwork : public GNMGenericNetwork
{
public:
    GNMDatabaseNetwork();
    virtual ~GNMDatabaseNetwork();
    virtual CPLErr Open( GDALOpenInfo* poOpenInfo ) override;
    virtual OGRErr      DeleteLayer(int) override;
    virtual CPLErr Create( const char* pszFilename, char** papszOptions ) override;
protected:
    virtual OGRLayer   *ICreateLayer( const char *pszName,
                                   OGRSpatialReference *poSpatialRef = nullptr,
                                   OGRwkbGeometryType eGType = wkbUnknown,
                                   char ** papszOptions = nullptr ) override;
    virtual int CheckNetworkExist( const char* pszFilename, char** papszOptions ) override;
protected:
    virtual CPLErr DeleteMetadataLayer() override;
    virtual CPLErr DeleteGraphLayer() override;
    virtual CPLErr DeleteFeaturesLayer() override;
    virtual CPLErr DeleteNetworkLayers() override;
    virtual CPLErr LoadNetworkLayer(const char* pszLayername) override;
    virtual bool CheckStorageDriverSupport(const char* pszDriverName) override;
protected:
    CPLErr FormName(const char* pszFilename, char** papszOptions);
    CPLErr DeleteLayerByName(const char* pszLayerName);
protected:
    GDALDataset* m_poDS;
    CPLString m_soNetworkFullName;
};

==> gdal-3.11.0.tar.gz: gdal-3.11.0/gnm/gnm_frmts/db/gnmdb.h <==
/******************************************************************************
 *
 * Project:  GDAL/OGR Geography Network support (Geographic Network Model)
 * Purpose:  GNM db based generic driver.
 * Authors:  Mikhail Gusev (gusevmihs at gmail dot com)
 *           Dmitry Baryshnikov, polimax@mail.ru
 *
 ******************************************************************************
 * Copyright (c) 2014, Mikhail Gusev
 * Copyright (c) 2014-2015, NextGIS <info@nextgis.com>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 ****************************************************************************/

#ifndef GNMDB_H_INCLUDED
#define GNMDB_H_INCLUDED

#include "gnm.h"

class GNMDatabaseNetwork : public GNMGenericNetwork
{
  public:
    GNMDatabaseNetwork();
    virtual ~GNMDatabaseNetwork();
    virtual CPLErr Open(GDALOpenInfo *poOpenInfo) override;
    virtual OGRErr DeleteLayer(int) override;
    virtual CPLErr Create(const char *pszFilename,
                          char **papszOptions) override;

  protected:
    OGRLayer *ICreateLayer(const char *pszName,
                           const OGRGeomFieldDefn *poGeomFieldDefn,
                           CSLConstList papszOptions) override;

    virtual int CheckNetworkExist(const char *pszFilename,
                                  char **papszOptions) override;

  protected:
    virtual CPLErr DeleteMetadataLayer() override;
    virtual CPLErr DeleteGraphLayer() override;
    virtual CPLErr DeleteFeaturesLayer() override;
    virtual CPLErr DeleteNetworkLayers() override;
    virtual CPLErr LoadNetworkLayer(const char *pszLayername) override;
    virtual bool CheckStorageDriverSupport(const char *pszDriverName) override;

  protected:
    CPLErr FormName(const char *pszFilename, char **papszOptions);
    CPLErr DeleteLayerByName(const char *pszLayerName);

  protected:
    GDALDataset *m_poDS;
    CPLString m_soNetworkFullName;
};

#endif  // GNMDB_H_INCLUDED
